@@ -23,12 +23,12 @@ public class UsersPanelToolbar extends JToolBar {
     public UsersPanelToolbar(UsersPanel _panel) {
         panel = _panel;
         
-        newRecord = new JButton(new ImageIcon("images/new.png"));
+        newRecord = new JButton(new ImageIcon(getClass().getResource("/images/new.png")));
         newRecord.setActionCommand(UsersPanelListener.AC_NEW);
         newRecord.setToolTipText("Add User");
         newRecord.addActionListener(panel.getListener());
         this.add(newRecord);
-        deleteRecord = new JButton(new ImageIcon("images/delete.png"));
+        deleteRecord = new JButton(new ImageIcon(getClass().getResource("/images/delete.png")));
         deleteRecord.setActionCommand(UsersPanelListener.AC_DELETE);
         deleteRecord.setToolTipText("Remove User");
         deleteRecord.addActionListener(panel.getListener());
