@@ -16,7 +16,7 @@ public class DatabaseList extends TreeInfo {
     /** Creates a new instance of DatabaseList */
     public DatabaseList(RootElement source) {
         super(source);
-        setIcon("./images/database.gif");
+        setIcon("/images/database.gif");
     }
     
     public void rebuildProperties() {
@@ -29,9 +29,7 @@ public class DatabaseList extends TreeInfo {
             }
             rs.close();
             prep.close();
-        } catch (SQLException e){
-            e.printStackTrace();
-        }
+        } catch (SQLException e){}
     }
     
     public long getOID() {
