@@ -19,7 +19,7 @@ public class GroupList extends TreeInfo {
     /** Creates a new instance of GroupList */
     public GroupList(RootElement  source) {
         super(source);
-        setIcon("./images/group.gif");
+        setIcon("/images/group.gif");
     }
     
     public long getOID() {
