@@ -19,7 +19,7 @@ public class SequenceList extends TreeInfo {
     /** Creates a new instance of SequenceList */
     public SequenceList(RootElement source) {
         super(source);
-        setIcon("./images/sequence.png");
+        setIcon("/images/sequence.png");
     }
     
     public void rebuildProperties() {
@@ -32,9 +32,7 @@ public class SequenceList extends TreeInfo {
             }
             rs.close();
             prep.close();
-        } catch (SQLException e){
-            e.printStackTrace();
-        }
+        } catch (SQLException e){}
     }
     
     public long getOID() {
