@@ -19,7 +19,7 @@ public class UserList extends TreeInfo {
     /** Creates a new instance of UserList */
     public UserList(RootElement source) {
         super(source);
-        setIcon("./images/user.png");
+        setIcon("/images/user.png");
     }
     
     public void rebuildProperties() {
