@@ -19,7 +19,7 @@ public class ViewList extends TreeInfo {
     /** Creates a new instance of ViewList */
     public ViewList(RootElement source) {
         super(source);
-        setIcon("./images/view.gif");
+        setIcon("/images/view.gif");
     }
     
     public void rebuildProperties() {
